@@ -30,8 +30,8 @@ class QueryService(Generic[T], GenericBase, ApplicationService):
 
     def __call__(self, **kwargs):
         try:
-            if self._type().id_column() in kwargs:
-                return self._registry(self._type()).find(kwargs[self._type().id_column()])
+            if self._type().id_name() in kwargs:
+                return self._registry(self._type()).find(kwargs[self._type().id_name()])
 
             if 'criteria' in kwargs:
                 criteria = kwargs['criteria']
